@@ -1,20 +1,22 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for polly service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.polly import PollyClient
-
-    session = boto3.Session()
+    from mypy_boto3_polly import PollyClient
 
     client: PollyClient = boto3.client("polly")
-    session_client: PollyClient = session.client("polly")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
+from typing import Any, Dict, List, Type, overload
+
 from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_polly.paginator import (
     DescribeVoicesPaginator,
     ListLexiconsPaginator,
@@ -66,19 +68,19 @@ class Exceptions:
 
 class PollyClient:
     """
-    [Polly.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Client)
+    [Polly.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Client.can_paginate)
         """
 
     def delete_lexicon(self, Name: str) -> Dict[str, Any]:
         """
-        [Client.delete_lexicon documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Client.delete_lexicon)
+        [Client.delete_lexicon documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Client.delete_lexicon)
         """
 
     def describe_voices(
@@ -119,7 +121,7 @@ class PollyClient:
         NextToken: str = None,
     ) -> DescribeVoicesOutputTypeDef:
         """
-        [Client.describe_voices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Client.describe_voices)
+        [Client.describe_voices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Client.describe_voices)
         """
 
     def generate_presigned_url(
@@ -130,22 +132,22 @@ class PollyClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Client.generate_presigned_url)
         """
 
     def get_lexicon(self, Name: str) -> GetLexiconOutputTypeDef:
         """
-        [Client.get_lexicon documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Client.get_lexicon)
+        [Client.get_lexicon documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Client.get_lexicon)
         """
 
     def get_speech_synthesis_task(self, TaskId: str) -> GetSpeechSynthesisTaskOutputTypeDef:
         """
-        [Client.get_speech_synthesis_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Client.get_speech_synthesis_task)
+        [Client.get_speech_synthesis_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Client.get_speech_synthesis_task)
         """
 
     def list_lexicons(self, NextToken: str = None) -> ListLexiconsOutputTypeDef:
         """
-        [Client.list_lexicons documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Client.list_lexicons)
+        [Client.list_lexicons documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Client.list_lexicons)
         """
 
     def list_speech_synthesis_tasks(
@@ -155,12 +157,12 @@ class PollyClient:
         Status: Literal["scheduled", "inProgress", "completed", "failed"] = None,
     ) -> ListSpeechSynthesisTasksOutputTypeDef:
         """
-        [Client.list_speech_synthesis_tasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Client.list_speech_synthesis_tasks)
+        [Client.list_speech_synthesis_tasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Client.list_speech_synthesis_tasks)
         """
 
     def put_lexicon(self, Name: str, Content: str) -> Dict[str, Any]:
         """
-        [Client.put_lexicon documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Client.put_lexicon)
+        [Client.put_lexicon documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Client.put_lexicon)
         """
 
     def start_speech_synthesis_task(
@@ -199,6 +201,7 @@ class PollyClient:
             "Justin",
             "Karl",
             "Kendra",
+            "Kevin",
             "Kimberly",
             "Lea",
             "Liv",
@@ -270,7 +273,7 @@ class PollyClient:
         TextType: Literal["ssml", "text"] = None,
     ) -> StartSpeechSynthesisTaskOutputTypeDef:
         """
-        [Client.start_speech_synthesis_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Client.start_speech_synthesis_task)
+        [Client.start_speech_synthesis_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Client.start_speech_synthesis_task)
         """
 
     def synthesize_speech(
@@ -308,6 +311,7 @@ class PollyClient:
             "Justin",
             "Karl",
             "Kendra",
+            "Kevin",
             "Kimberly",
             "Lea",
             "Liv",
@@ -377,19 +381,19 @@ class PollyClient:
         TextType: Literal["ssml", "text"] = None,
     ) -> SynthesizeSpeechOutputTypeDef:
         """
-        [Client.synthesize_speech documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Client.synthesize_speech)
+        [Client.synthesize_speech documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Client.synthesize_speech)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_voices"]) -> DescribeVoicesPaginator:
         """
-        [Paginator.DescribeVoices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Paginator.DescribeVoices)
+        [Paginator.DescribeVoices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Paginator.DescribeVoices)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_lexicons"]) -> ListLexiconsPaginator:
         """
-        [Paginator.ListLexicons documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Paginator.ListLexicons)
+        [Paginator.ListLexicons documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Paginator.ListLexicons)
         """
 
     @overload
@@ -397,5 +401,8 @@ class PollyClient:
         self, operation_name: Literal["list_speech_synthesis_tasks"]
     ) -> ListSpeechSynthesisTasksPaginator:
         """
-        [Paginator.ListSpeechSynthesisTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Paginator.ListSpeechSynthesisTasks)
+        [Paginator.ListSpeechSynthesisTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Paginator.ListSpeechSynthesisTasks)
         """
+
+    def get_paginator(self, operation_name: str) -> Boto3Paginator:
+        pass
