@@ -1,10 +1,14 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for polly service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.polly import (
+
+    from mypy_boto3_polly import PollyClient
+    from mypy_boto3_polly.paginator import (
         DescribeVoicesPaginator,
         ListLexiconsPaginator,
         ListSpeechSynthesisTasksPaginator,
@@ -15,11 +19,13 @@ Usage::
     describe_voices_paginator: DescribeVoicesPaginator = client.get_paginator("describe_voices")
     list_lexicons_paginator: ListLexiconsPaginator = client.get_paginator("list_lexicons")
     list_speech_synthesis_tasks_paginator: ListSpeechSynthesisTasksPaginator = client.get_paginator("list_speech_synthesis_tasks")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Iterator, TYPE_CHECKING
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_polly.type_defs import (
     DescribeVoicesOutputTypeDef,
     ListLexiconsOutputTypeDef,
@@ -38,7 +44,7 @@ __all__ = ("DescribeVoicesPaginator", "ListLexiconsPaginator", "ListSpeechSynthe
 
 class DescribeVoicesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeVoices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Paginator.DescribeVoices)
+    [Paginator.DescribeVoices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Paginator.DescribeVoices)
     """
 
     def paginate(
@@ -79,26 +85,26 @@ class DescribeVoicesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeVoicesOutputTypeDef]:
         """
-        [DescribeVoices.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Paginator.DescribeVoices.paginate)
+        [DescribeVoices.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Paginator.DescribeVoices.paginate)
         """
 
 
 class ListLexiconsPaginator(Boto3Paginator):
     """
-    [Paginator.ListLexicons documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Paginator.ListLexicons)
+    [Paginator.ListLexicons documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Paginator.ListLexicons)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListLexiconsOutputTypeDef]:
         """
-        [ListLexicons.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Paginator.ListLexicons.paginate)
+        [ListLexicons.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Paginator.ListLexicons.paginate)
         """
 
 
 class ListSpeechSynthesisTasksPaginator(Boto3Paginator):
     """
-    [Paginator.ListSpeechSynthesisTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Paginator.ListSpeechSynthesisTasks)
+    [Paginator.ListSpeechSynthesisTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Paginator.ListSpeechSynthesisTasks)
     """
 
     def paginate(
@@ -107,5 +113,5 @@ class ListSpeechSynthesisTasksPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListSpeechSynthesisTasksOutputTypeDef]:
         """
-        [ListSpeechSynthesisTasks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.5/reference/services/polly.html#Polly.Paginator.ListSpeechSynthesisTasks.paginate)
+        [ListSpeechSynthesisTasks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/polly.html#Polly.Paginator.ListSpeechSynthesisTasks.paginate)
         """
